Module error

Module error 

Error types for schema parsing, RON parsing, and validation.

Structs

RonParseError
An error produced when parsing a .ron data file fails.
SchemaParseError
An error produced when parsing a .ronschema file fails.
ValidationError
An error produced when RON data does not conform to a schema.
ValidationResult
The result of validating RON data against a schema.
Warning
A warning produced during validation — informational, does not indicate invalid data.

Enums

ErrorKind
Specific kinds of validation errors produced when RON data does not match a schema.
RonErrorKind
Specific kinds of errors that can occur when parsing a .ron data file.
SchemaErrorKind
Specific kinds of errors that can occur when parsing a .ronschema file.
WarningKind
Specific kinds of warnings produced during validation.