ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
Show 16 variants MissingField { field_name: String, }, UnknownField { field_name: String, }, TypeMismatch { expected: String, found: String, }, InvalidEnumVariant { enum_name: String, variant: String, valid: Vec<String>, }, InvalidOptionValue { expected: String, found: String, }, InvalidListElement { index: usize, expected: String, found: String, }, ExpectedStruct { found: String, }, ExpectedList { found: String, }, ExpectedOption { found: String, }, ExpectedMap { found: String, }, InvalidMapKey { key: String, expected: String, found: String, }, InvalidMapValue { key: String, expected: String, found: String, }, InvalidVariantData { enum_name: String, variant: String, expected: String, found: String, }, ExpectedTuple { found: String, }, TupleLengthMismatch { expected: usize, found: usize, }, InvalidTupleElement { index: usize, expected: String, found: String, },
}
Specific kinds of validation errors produced when RON data does not match a schema.

Variants



MissingField

A required field defined in the schema is absent from the data.

Fields

field_name: String

The name of the missing field.



UnknownField

The data contains a field not defined in the schema.

Fields

field_name: String

The name of the unrecognized field.



TypeMismatch

A value exists but has the wrong type.

Fields

expected: String

The type expected by the schema.

found: String

A description of what was actually found.



InvalidEnumVariant

A bare identifier does not match any variant of the expected enum.

Fields

enum_name: String

The enum the identifier was validated against.

variant: String

The identifier that was found.

valid: Vec<String>

All valid variants for this enum.



InvalidOptionValue

The value inside Some(...) has the wrong type.

Fields

expected: String

The type expected by the schema.

found: String

A description of what was actually found.



InvalidListElement

A list element has the wrong type.

Fields

index: usize

The 0-based index of the offending element.

expected: String

The type expected by the schema.

found: String

A description of what was actually found.



ExpectedStruct

Expected a struct (...) but found a non-struct value.

Fields

found: String

A description of what was actually found.



ExpectedList

Expected a list [...] but found a non-list value.

Fields

found: String

A description of what was actually found.



ExpectedOption

Expected Some(...) or None but found something else.

Fields

found: String

A description of what was actually found.



ExpectedMap

Expected a map { ... } but found a non-map value.

Fields

found: String

A description of what was actually found.



InvalidMapKey

A map key has the wrong type.

Fields

key: String

A string representation of the key.

expected: String

The type expected by the schema.

found: String

A description of what was actually found.



InvalidMapValue

A map value has the wrong type.

Fields

key: String

A string representation of the key this value belongs to.

expected: String

The type expected by the schema.

found: String

A description of what was actually found.



InvalidVariantData

An enum variant’s associated data does not match the expected type.

Fields

enum_name: String

The enum name.

variant: String

The variant name.

expected: String

The type expected by the schema.

found: String

A description of what was actually found.



ExpectedTuple

Expected a tuple (...) but found a non-tuple value.

Fields

found: String

A description of what was actually found.



TupleLengthMismatch

A tuple has the wrong number of elements.

Fields

expected: usize

The number of elements expected by the schema.

found: usize

The number of elements found in the data.



InvalidTupleElement

A tuple element has the wrong type.

Fields

index: usize

The 0-based index of the offending element.

expected: String

The type expected by the schema.

found: String

A description of what was actually found.