WarningKind

Enum WarningKind 

pub enum WarningKind {
    FieldOrderMismatch {
        field_name: String,
        expected_after: String,
    },
}
Specific kinds of warnings produced during validation.

Variants



FieldOrderMismatch

Fields in the data appear in a different order than declared in the schema.

Fields

field_name: String

The field that appears out of order.

expected_after: String

The field that should have appeared before it according to the schema.