pub fn parse_ron(source: &str) -> Result<Spanned<RonValue>, RonParseError>Expand description
Parses a RON data source string into a spanned value tree.
Errors
Returns a RonParseError if the source contains syntax errors.
pub fn parse_ron(source: &str) -> Result<Spanned<RonValue>, RonParseError>Parses a RON data source string into a spanned value tree.
Returns a RonParseError if the source contains syntax errors.