Error types for schema parsing, RON parsing, and validation.
Structs
- RonParse
Error - An error produced when parsing a
.rondata file fails. - Schema
Parse Error - An error produced when parsing a
.ronschemafile fails. - Validation
Error - An error produced when RON data does not conform to a schema.
- Validation
Result - The result of validating RON data against a schema.
- Warning
- A warning produced during validation — informational, does not indicate invalid data.
Enums
- Error
Kind - Specific kinds of validation errors produced when RON data does not match a schema.
- RonError
Kind - Specific kinds of errors that can occur when parsing a
.rondata file. - Schema
Error Kind - Specific kinds of errors that can occur when parsing a
.ronschemafile. - Warning
Kind - Specific kinds of warnings produced during validation.