Error types for schema parsing, RON parsing, and validation.
Structs
- RonParse
Error - An error produced when parsing a
.rondata file fails. - Schema
Parse Error - An error produced when parsing a
.ronschemafile fails. - Validation
Error - An error produced when RON data does not conform to a schema.
Enums
- Error
Kind - Specific kinds of validation errors produced when RON data does not match a schema.
- RonError
Kind - Specific kinds of errors that can occur when parsing a
.rondata file. - Schema
Error Kind - Specific kinds of errors that can occur when parsing a
.ronschemafile.