Module error

Module error 

Error types for schema parsing, RON parsing, and validation.

Structs

RonParseError
An error produced when parsing a .ron data file fails.
SchemaParseError
An error produced when parsing a .ronschema file fails.
ValidationError
An error produced when RON data does not conform to a schema.

Enums

ErrorKind
Specific kinds of validation errors produced when RON data does not match a schema.
RonErrorKind
Specific kinds of errors that can occur when parsing a .ron data file.
SchemaErrorKind
Specific kinds of errors that can occur when parsing a .ronschema file.