Schema AST types representing a parsed .ronschema file.
Modules
Structs
- EnumDef
- A named enum with a closed set of unit variants.
- Field
Def - A single field definition within a struct.
- Schema
- The top-level schema produced by parsing a
.ronschemafile. - Struct
Def - A struct definition containing an ordered list of field definitions.
Enums
- Schema
Type - A type descriptor representing the expected type of a field value.